<?php
/*
 * Author Rudyuk Vitalij Anatolievich
 * Email rvansp@gmail.com
 * Blog www.cervic.info
 */
namespace Infomodus\Upslabel\Helper;
class Config extends \Magento\Framework\App\Helper\AbstractHelper
{
    public $objectManager;
    public $error = true;
    public $testing = false;
    private $ch;

    public function __construct(\Magento\Framework\App\Helper\Context $context, \Magento\Framework\ObjectManagerInterface $objectManager)
    {
        $this->objectManager = $objectManager;
        parent::__construct($context);
    }

    public function log($error, array $context = [])
    {
        $this->_logger->error($error, $context);
    }

    public function getBaseDir($alias)
    {
        $filesystem = $this->objectManager->get('Magento\Framework\Filesystem');
        $reader = $filesystem->getDirectoryRead($alias);
        return $reader->getAbsolutePath();
    }

    public function getBaseUrl($alias)
    {
        $filesystem = $this->objectManager->get('Magento\Store\Model\StoreManagerInterface');
        return $filesystem->getStore()->getBaseUrl($alias);
    }

    public function getStoreConfig($configPath, $scopeCode = NULL)
    {
        return $this->scopeConfig->getValue(
            $configPath,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE,
            $scopeCode
        );
    }

    public function getRequest()
    {
        return $this->_getRequest();
    }
    public function getUrl($route, $params = [])
    {
        return parent::_getUrl($route, $params = []);
    }

    public function getModel()
    {
        return $this->objectManager;
    }

    public function escapeXML($string)
    {
        $string = preg_replace('/&/is', '&amp;', $string);
        $string = preg_replace('/</is', '&lt;', $string);
        $string = preg_replace('/>/is', '&gt;', $string);
        $string = preg_replace('/\'/is', '&#39;', $string);
        $string = preg_replace('/"/is', '&quot;', $string);
        $string = str_replace(['ą', 'ć', 'ę', 'ł', 'ń', 'ó', 'ś', 'ź', 'ż', 'Ą', 'Ć', 'Ę', 'Ł', 'Ń', 'Ó', 'Ś', 'Ź', 'Ż', 'ü', 'ò', 'è', 'à', 'ì'], ['a', 'c', 'e', 'l', 'n', 'o', 's', 'z', 'z', 'A', 'C', 'E', 'L', 'N', 'O', 'S', 'Z', 'Z', 'u', 'o', 'e', 'a', 'i'], $string);
        return mb_encode_numericentity(trim($string), [0x80, 0xffff, 0, 0xffff], 'UTF-8');
    }

    public function curlSend($url, $data = NULL)
    {
        $this->error = true;
        $result = $this->curlSetOption($url, $data);
        $ch = $this->ch;
        if ($result) {
            $result1 = $result;
            $result = strstr($result, '<?xml');
            if ($result === FALSE) {
                $result = $result1;
            }
            curl_close($ch);
            $this->error = false;
            return $result;
        } else {
            curl_close($ch);
            $this->error = true;
            return ['errordesc' => 'Server Error (cUrl)', 'error' => curl_errno($ch) . ' - ' . curl_error($ch)];
        }
    }

    public function curlSetOption($url, $data = NULL)
    {
        /*$sslV = curl_version();*/
        $ch = curl_init($url);
        /*if ($data != NULL) {
            curl_setopt($ch, CURLOPT_HEADER, 1);
        } else {*/
            curl_setopt($ch, CURLOPT_HEADER, 0);
        /*}*/

        curl_setopt($ch, CURLOPT_TIMEOUT, 30);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, $this->testing);
        /*curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);*/
        /*if (strpos($sslV['ssl_version'], 'NSS/') === FALSE) {
            curl_setopt($ch, CURLOPT_SSL_CIPHER_LIST, 'TLSv1.2');
        }*/
        if ($data !== NULL) {
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
        }
        $this->ch = $ch;
        return curl_exec($ch);
    }

    public function sendPrint($data, $storeId = NULL)
    {
        $ip = trim($this->getStoreConfig('upslabel/printing/automatic_printing_ip', $storeId));
        $port = trim($this->getStoreConfig('upslabel/printing/automatic_printing_port', $storeId));
        $socket = socket_create(AF_INET, SOCK_STREAM, SOL_TCP);
        if ($socket === false) {
            $this->_logger->error("socket_create() failed: reason: " . socket_strerror(socket_last_error()));
            echo "socket_create() failed: reason: " . socket_strerror(socket_last_error()); exit;
        } else {
            $result = socket_connect($socket, $ip, $port);
            if ($result === false) {
                $this->_logger->error("socket_connect() failed.\nReason: (".$ip.":".$port.") " . socket_strerror(socket_last_error($socket)));
                echo "socket_connect() failed.\nReason: (".$ip.":".$port.") " . socket_strerror(socket_last_error($socket)); exit;
            } else {
                socket_write($socket, $data, strlen($data));
            }
            socket_close($socket);
        }
    }

    /*multistore*/
    public function getStoreByCode($storeCode)
    {
        $manager = $this->objectManager->get('Magento\Store\Model\StoreManagerInterface');
        $stores = array_keys($manager->getStores());
        foreach ($stores as $id) {
            $store = $manager->getStore($id);
            if ($store->getCode() == $storeCode) {
                return $store;
            }
        }
        return null; // if not found
    }
    /*multistore*/

    public function getUpsCode($code){
        $codes = [
            '1DM' => '14',
            '1DA' => '01',
            '1DP' => '13',
            '2DM' => '59',
            '2DA' => '02',
            '3DS' => '12',
            'GND' => '03',
            'EP' => '54',
            'XDM' => '54',
            'XPD' => '08',
            'XPR' => '07',
            'ES' => '07',
            'SV' => '65',
            'EX' => '08',
            'ST' => '11',
            'ND' => '07',
            'WXS' => '65',
        ];
        return isset($codes[$code])?$codes[$code]:null;
    }
}