<?php
/**
 * Copyright © 2015 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Infomodus\Upslabel\Observer;

use Magento\Framework\Event\ObserverInterface;

class OrderPlaceAfter implements ObserverInterface
{
    protected $_coreRegistry;
    protected $_handy;

    public function __construct(
        \Magento\Framework\Registry $registry,
        \Infomodus\Upslabel\Helper\Handy $handy
    )
    {
        $this->_coreRegistry = $registry;
        $this->_handy = $handy;
    }

    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        $order = $observer->getEvent()->getOrder();
        if (!$order->getId()) {
            //order not saved in the database
            return $this;
        }
        /*multistore*/
        $storeId = $order->getStoreId();
        /*multistore*/
        $globalData = $this->_coreRegistry->registry('infomodus_upslabel_autocreate_label');
        if ($globalData !== NULL) {
            if ($this->_handy->_conf->getStoreConfig('upslabel/frontend_autocreate_label/frontend_order_autocreate_label_enable' /*multistore*/, $storeId /*multistore*/) == 1) {
                $shippingActiveMethods = trim($this->_handy->_conf->getStoreConfig('upslabel/frontend_autocreate_label/apply_to', $storeId), " ,");
                $shippingActiveMethods = strlen($shippingActiveMethods) > 0 ? explode(",", $shippingActiveMethods) : [];
                $orderStatuses = explode(",", trim($this->_handy->_conf->getStoreConfig('upslabel/frontend_autocreate_label/orderstatus', $storeId), " ,"));
                if (
                    (
                        !isset($globalData['order_id']) || $globalData['order_id'] === NULL || !isset($globalData['status']) || $globalData['status'] != $order->getStatus()
                    )
                    && isset($shippingActiveMethods)
                    && count($shippingActiveMethods) > 0
                    && in_array($order->getShippingMethod(), $shippingActiveMethods)
                    && isset($orderStatuses) && count($orderStatuses) > 0 && in_array($order->getStatus(), $orderStatuses)
                ) {
                    $shipment = $order->getShipmentsCollection();
                    $isBeLabel = true;
                    $shipmentId = NULL;
                    if (count($shipment) > 0) {
                        $shipment = $shipment->getFirstItem();
                        $shipmentId = $shipment->getId();
                        $label = $this->_handy->_conf->objectManager->create('Infomodus\Upslabel\Model\Items')->getCollection()
                            ->addFieldToFilter('type', 'shipment')
                            ->addFieldToFilter('lstatus', 0)
                            ->addFieldToFilter('order_id', $order->getId())
                            ->addFieldToFilter('shipment_id', $shipment->getId());
                        if (count($label) > 0) {
                            $isBeLabel = false;
                        }
                    }
                    if ($isBeLabel) {
                        $this->_handy->intermediate($order->getId(), 'shipment');
                        $this->_handy->defConfParams['package'] = $this->_handy->defPackageParams;
                        $this->_handy->getLabel(NULL, 'shipment', $shipmentId, $this->_handy->defConfParams);
                    }
                }
            }
            $this->_coreRegistry->unregister('infomodus_upslabel_autocreate_label');
        }
        return $this;
    }
}
